package com.aucma.dms.service;

//import com.aucma.dms.domain.DmsBaseOutsrcInfo;

import com.aucma.dms.domain.DmsBaseOutsrcInfo;

import java.util.List;

/**
 * 外协信息Service接口
 * 
 * @author Open Platform
 * @date 2024-01-11
 */
public interface IDmsBaseOutsrcInfoService 
{
    /**
     * 查询外协信息
     * 
     * @param outsrcId 外协信息主键
     * @return 外协信息
     */
    public DmsBaseOutsrcInfo selectDmsBaseOutsrcInfoByOutsrcId(Long outsrcId);

    /**
     * 查询外协信息列表
     * 
     * @param dmsBaseOutsrcInfo 外协信息
     * @return 外协信息集合
     */
    public List<DmsBaseOutsrcInfo> selectDmsBaseOutsrcInfoList(DmsBaseOutsrcInfo dmsBaseOutsrcInfo);

    /**
     * 新增外协信息
     * 
     * @param dmsBaseOutsrcInfo 外协信息
     * @return 结果
     */
    public int insertDmsBaseOutsrcInfo(DmsBaseOutsrcInfo dmsBaseOutsrcInfo);

    /**
     * 修改外协信息
     * 
     * @param dmsBaseOutsrcInfo 外协信息
     * @return 结果
     */
    public int updateDmsBaseOutsrcInfo(DmsBaseOutsrcInfo dmsBaseOutsrcInfo);

    /**
     * 批量删除外协信息
     * 
     * @param outsrcIds 需要删除的外协信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseOutsrcInfoByOutsrcIds(Long[] outsrcIds);

    /**
     * 删除外协信息信息
     * 
     * @param outsrcId 外协信息主键
     * @return 结果
     */
    public int deleteDmsBaseOutsrcInfoByOutsrcId(Long outsrcId);
}
